﻿using System;
using Microsoft.EntityFrameworkCore.Migrations;

namespace EaCloud.Template.Svc.Migrations
{
    public partial class InitialCreate : Migration
    {
        protected override void Up(MigrationBuilder migrationBuilder)
        {
            migrationBuilder.CreateTable(
                name: "AUD_AuditOperation",
                columns: table => new
                {
                    Id = table.Column<Guid>(type: "uniqueidentifier", maxLength: 80, nullable: false, comment: "编号"),
                    FunctionName = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "执行的功能名"),
                    UserId = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "当前用户标识"),
                    UserName = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "当前用户名"),
                    NickName = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "当前用户昵称"),
                    Ip = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "当前访问IP"),
                    OperationSystem = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "操作系统"),
                    Browser = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "浏览器"),
                    UserAgent = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "当前访问用户代理"),
                    ResultType = table.Column<int>(type: "int", nullable: false, comment: "操作结果"),
                    Message = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "消息"),
                    Elapsed = table.Column<int>(type: "int", nullable: false, comment: "执行耗时（毫秒）"),
                    CreatedTime = table.Column<DateTime>(type: "datetime2", nullable: false, comment: "信息添加时间")
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_AUD_AuditOperation", x => x.Id);
                });

            migrationBuilder.CreateTable(
                name: "AUZ_EntityInfo",
                columns: table => new
                {
                    Id = table.Column<Guid>(type: "uniqueidentifier", maxLength: 80, nullable: false, comment: "编号"),
                    Name = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "实体名称"),
                    TypeName = table.Column<string>(type: "nvarchar(450)", nullable: false, comment: "实体类型名称"),
                    TableName = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "实体表名称"),
                    AuditEnabled = table.Column<bool>(type: "bit", nullable: false, comment: "是否数据审计"),
                    PropertyJson = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "实体属性信息Json字符串")
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_AUZ_EntityInfo", x => x.Id);
                });

            migrationBuilder.CreateTable(
                name: "AUZ_Function",
                columns: table => new
                {
                    Id = table.Column<Guid>(type: "uniqueidentifier", maxLength: 80, nullable: false, comment: "编号"),
                    Name = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "功能名称"),
                    Area = table.Column<string>(type: "nvarchar(450)", nullable: false, comment: "区域"),
                    Controller = table.Column<string>(type: "nvarchar(450)", nullable: false, comment: "控制器"),
                    Action = table.Column<string>(type: "nvarchar(450)", nullable: false, comment: "功能"),
                    IsController = table.Column<bool>(type: "bit", nullable: false, comment: "是否控制器"),
                    IsAjax = table.Column<bool>(type: "bit", nullable: false, comment: "是否Ajax功能"),
                    AccessType = table.Column<int>(type: "int", nullable: false, comment: "访问类型"),
                    IsAccessTypeChanged = table.Column<bool>(type: "bit", nullable: false, comment: "访问类型是否更改"),
                    AuditOperationEnabled = table.Column<bool>(type: "bit", nullable: false, comment: "是否操作审计"),
                    AuditEntityEnabled = table.Column<bool>(type: "bit", nullable: false, comment: "是否数据审计"),
                    CacheExpirationSeconds = table.Column<int>(type: "int", nullable: false, comment: "数据缓存秒数"),
                    IsCacheSliding = table.Column<bool>(type: "bit", nullable: false, comment: "是否相对过期时间"),
                    IsSlaveDatabase = table.Column<bool>(type: "bit", nullable: false, comment: "是否从库"),
                    IsLocked = table.Column<bool>(type: "bit", nullable: false, comment: "是否锁定")
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_AUZ_Function", x => x.Id);
                });

            migrationBuilder.CreateTable(
                name: "AUZ_Module",
                columns: table => new
                {
                    Id = table.Column<long>(type: "bigint", maxLength: 80, nullable: false, comment: "编号"),
                    Name = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "模块名称"),
                    Remark = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "模块描述"),
                    Code = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "模块代码"),
                    OrderCode = table.Column<decimal>(type: "decimal(22,10)", precision: 22, scale: 10, nullable: false, comment: "排序码"),
                    TreePathString = table.Column<string>(type: "nvarchar(450)", nullable: false, comment: "父节点树形路径"),
                    ParentId = table.Column<long>(type: "bigint", nullable: true, comment: "父模块编号")
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_AUZ_Module", x => x.Id);
                    table.ForeignKey(
                        name: "FK_Module_ParentId",
                        column: x => x.ParentId,
                        principalTable: "AUZ_Module",
                        principalColumn: "Id",
                        onDelete: ReferentialAction.Restrict);
                });

            migrationBuilder.CreateTable(
                name: "DMO_Demo",
                columns: table => new
                {
                    Id = table.Column<long>(type: "bigint", maxLength: 80, nullable: false, comment: "编号"),
                    String = table.Column<string>(type: "nvarchar(150)", maxLength: 150, nullable: false, comment: "String"),
                    StringCanNull = table.Column<string>(type: "nvarchar(max)", nullable: true, comment: "StringCanNull"),
                    Decimal = table.Column<decimal>(type: "decimal(22,10)", precision: 22, scale: 10, nullable: false, comment: "Decimal"),
                    DecimalCanNull = table.Column<decimal>(type: "decimal(18,2)", nullable: true, comment: "DecimalCanNull"),
                    Bool = table.Column<bool>(type: "bit", nullable: false, comment: "Bool"),
                    Guid = table.Column<Guid>(type: "uniqueidentifier", nullable: false, comment: "Guid"),
                    Bytes = table.Column<byte[]>(type: "varbinary(max)", nullable: true, comment: "Bytes"),
                    OrganizationId = table.Column<long>(type: "bigint", nullable: true, comment: "组织机构编号"),
                    DataVersion = table.Column<long>(type: "bigint", nullable: false, comment: "数据版本"),
                    CreatorId = table.Column<long>(type: "bigint", nullable: true, comment: "创建者编号"),
                    CreatedTime = table.Column<DateTime>(type: "datetime2", nullable: false, comment: "创建时间"),
                    LastUpdaterId = table.Column<long>(type: "bigint", nullable: true, comment: "更新者编号"),
                    LastUpdatedTime = table.Column<DateTime>(type: "datetime2", nullable: true, comment: "最后更新时间"),
                    DeletedTime = table.Column<DateTime>(type: "datetime2", nullable: true, comment: "删除时间")
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_DMO_Demo", x => x.Id);
                });

            migrationBuilder.CreateTable(
                name: "FIE_FileArchive",
                columns: table => new
                {
                    Id = table.Column<long>(type: "bigint", maxLength: 80, nullable: false, comment: "编号"),
                    FileIntroId = table.Column<long>(type: "bigint", nullable: false, comment: "文件ID"),
                    FileName = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "文件名称"),
                    FileExt = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "文件扩展名"),
                    SHA1 = table.Column<string>(type: "nvarchar(450)", nullable: false, comment: "文件SHA1值"),
                    MD5 = table.Column<string>(type: "nvarchar(450)", nullable: false, comment: "文件MD5值"),
                    Size = table.Column<long>(type: "bigint", nullable: false, comment: "文件大小(bytes)"),
                    SerializedName = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "文件序列化名称"),
                    StoreMode = table.Column<int>(type: "int", nullable: false, comment: "存储方式"),
                    PhysicalPath = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "物理存储路径"),
                    ContainerName = table.Column<string>(type: "nvarchar(max)", nullable: true, comment: "存储服务容器名称"),
                    RequestPath = table.Column<string>(type: "nvarchar(max)", nullable: true, comment: "文件请求路径"),
                    Comments = table.Column<string>(type: "nvarchar(max)", nullable: true, comment: "备注"),
                    FileVersion = table.Column<long>(type: "bigint", nullable: false, comment: "文件版本"),
                    UploadSource = table.Column<string>(type: "nvarchar(450)", nullable: false, comment: "上传源"),
                    UploadIdent = table.Column<string>(type: "nvarchar(450)", nullable: false, comment: "上传标识"),
                    UploadRef = table.Column<string>(type: "nvarchar(max)", nullable: true, comment: "上传参考"),
                    FileByte = table.Column<byte[]>(type: "varbinary(max)", nullable: false, comment: "文件字节"),
                    CreatedTime = table.Column<DateTime>(type: "datetime2", nullable: false, comment: "创建时间"),
                    CreatorId = table.Column<long>(type: "bigint", nullable: true, comment: "创建者编号")
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_FIE_FileArchive", x => x.Id);
                });

            migrationBuilder.CreateTable(
                name: "FIE_FileContent",
                columns: table => new
                {
                    Id = table.Column<long>(type: "bigint", maxLength: 80, nullable: false, comment: "编号"),
                    FileIntroId = table.Column<long>(type: "bigint", nullable: false, comment: "文件ID"),
                    SHA1 = table.Column<string>(type: "nvarchar(450)", nullable: false, comment: "文件SHA1值"),
                    MD5 = table.Column<string>(type: "nvarchar(450)", nullable: false, comment: "文件MD5值"),
                    FileByte = table.Column<byte[]>(type: "varbinary(max)", nullable: false, comment: "文件字节"),
                    DataVersion = table.Column<long>(type: "bigint", nullable: false, comment: "数据版本"),
                    CreatedTime = table.Column<DateTime>(type: "datetime2", nullable: false, comment: "创建时间")
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_FIE_FileContent", x => x.Id);
                });

            migrationBuilder.CreateTable(
                name: "FIE_FileIntro",
                columns: table => new
                {
                    Id = table.Column<long>(type: "bigint", maxLength: 80, nullable: false, comment: "编号"),
                    FileName = table.Column<string>(type: "nvarchar(450)", nullable: false, comment: "文件名称"),
                    FileExt = table.Column<string>(type: "nvarchar(450)", nullable: false, comment: "文件扩展名"),
                    SHA1 = table.Column<string>(type: "nvarchar(450)", nullable: false, comment: "文件SHA1值"),
                    MD5 = table.Column<string>(type: "nvarchar(450)", nullable: false, comment: "文件MD5值"),
                    Size = table.Column<long>(type: "bigint", nullable: false, comment: "文件大小(bytes)"),
                    SerializedName = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "文件序列化名称"),
                    StoreMode = table.Column<int>(type: "int", nullable: false, comment: "存储方式"),
                    PhysicalPath = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "物理存储路径"),
                    ContainerName = table.Column<string>(type: "nvarchar(max)", nullable: true, comment: "存储服务容器名称"),
                    RequestPath = table.Column<string>(type: "nvarchar(max)", nullable: true, comment: "文件请求路径"),
                    Comments = table.Column<string>(type: "nvarchar(max)", nullable: true, comment: "备注"),
                    FileVersion = table.Column<long>(type: "bigint", nullable: false, comment: "文件版本"),
                    UploadSource = table.Column<string>(type: "nvarchar(450)", nullable: false, comment: "上传源"),
                    UploadIdent = table.Column<string>(type: "nvarchar(450)", nullable: false, comment: "上传标识"),
                    UploadRef = table.Column<string>(type: "nvarchar(max)", nullable: true, comment: "上传参考"),
                    DataVersion = table.Column<long>(type: "bigint", nullable: false, comment: "数据版本"),
                    CreatedTime = table.Column<DateTime>(type: "datetime2", nullable: false, comment: "创建时间"),
                    CreatorId = table.Column<long>(type: "bigint", nullable: true, comment: "创建者编号"),
                    LastUpdaterId = table.Column<long>(type: "bigint", nullable: true, comment: "更新者编号"),
                    LastUpdatedTime = table.Column<DateTime>(type: "datetime2", nullable: true, comment: "最后更新时间")
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_FIE_FileIntro", x => x.Id);
                });

            migrationBuilder.CreateTable(
                name: "FIE_FileRecord",
                columns: table => new
                {
                    Id = table.Column<long>(type: "bigint", maxLength: 80, nullable: false, comment: "编号"),
                    RecordType = table.Column<int>(type: "int", nullable: false, comment: "记录类型"),
                    FileIntroId = table.Column<long>(type: "bigint", nullable: false, comment: "文件ID"),
                    FileVersion = table.Column<long>(type: "bigint", nullable: false, comment: "文件版本"),
                    CreatedTime = table.Column<DateTime>(type: "datetime2", nullable: false, comment: "创建时间"),
                    CreatorId = table.Column<long>(type: "bigint", nullable: true, comment: "创建者编号")
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_FIE_FileRecord", x => x.Id);
                });

            migrationBuilder.CreateTable(
                name: "IDT_Organization",
                columns: table => new
                {
                    Id = table.Column<long>(type: "bigint", maxLength: 80, nullable: false, comment: "编号"),
                    LogoImg = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "组织LOGO"),
                    OrgType = table.Column<int>(type: "int", nullable: false, comment: "组织机构类型"),
                    OrgName = table.Column<string>(type: "nvarchar(150)", maxLength: 150, nullable: false, comment: "组织机构名称"),
                    NormalizedName = table.Column<string>(type: "nvarchar(150)", maxLength: 150, nullable: false, comment: "标准化角色名称"),
                    OrgNameFrgn = table.Column<string>(type: "nvarchar(150)", maxLength: 150, nullable: false, comment: "组织机构名称（外文）"),
                    Address = table.Column<string>(type: "nvarchar(150)", maxLength: 150, nullable: false, comment: "地址"),
                    AddressFrgn = table.Column<string>(type: "nvarchar(150)", maxLength: 150, nullable: false, comment: "地址（外文）"),
                    PrintHeader = table.Column<string>(type: "nvarchar(150)", maxLength: 150, nullable: false, comment: "打印抬头"),
                    PrintHeaderFrgn = table.Column<string>(type: "nvarchar(150)", maxLength: 150, nullable: false, comment: "打印抬头（外文）"),
                    ReptName = table.Column<string>(type: "nvarchar(150)", maxLength: 150, nullable: false, comment: "报表名称"),
                    ReptNameFrgn = table.Column<string>(type: "nvarchar(150)", maxLength: 150, nullable: false, comment: "报表名称（外文）"),
                    Remark = table.Column<string>(type: "nvarchar(512)", maxLength: 512, nullable: false, comment: "备注"),
                    OrderCode = table.Column<decimal>(type: "decimal(22,10)", precision: 22, scale: 10, nullable: false, comment: "排序码"),
                    TreePathString = table.Column<string>(type: "nvarchar(450)", nullable: false, comment: "父节点树形路径"),
                    ParentId = table.Column<long>(type: "bigint", nullable: true, comment: "父组织机构编号"),
                    EnableLogin = table.Column<bool>(type: "bit", nullable: false, comment: "启用登陆"),
                    IsDefault = table.Column<bool>(type: "bit", nullable: false, comment: "默认组织机构"),
                    IsSystem = table.Column<bool>(type: "bit", nullable: false, comment: "是否系统组织机构"),
                    DataVersion = table.Column<long>(type: "bigint", nullable: false, comment: "数据版本"),
                    IsLocked = table.Column<bool>(type: "bit", nullable: false, comment: "是否锁定"),
                    CreatedTime = table.Column<DateTime>(type: "datetime2", nullable: false, comment: "创建时间"),
                    LastUpdaterId = table.Column<long>(type: "bigint", nullable: true, comment: "更新者编号"),
                    LastUpdatedTime = table.Column<DateTime>(type: "datetime2", nullable: true, comment: "最后更新时间"),
                    DeletedTime = table.Column<DateTime>(type: "datetime2", nullable: true, comment: "删除时间")
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_IDT_Organization", x => x.Id);
                    table.ForeignKey(
                        name: "FK_Organization_ParentId",
                        column: x => x.ParentId,
                        principalTable: "IDT_Organization",
                        principalColumn: "Id",
                        onDelete: ReferentialAction.Restrict);
                });

            migrationBuilder.CreateTable(
                name: "IDT_Role",
                columns: table => new
                {
                    Id = table.Column<long>(type: "bigint", maxLength: 80, nullable: false, comment: "编号"),
                    Name = table.Column<string>(type: "nvarchar(150)", maxLength: 150, nullable: false, comment: "角色名称"),
                    NormalizedName = table.Column<string>(type: "nvarchar(450)", nullable: false, comment: "标准化角色名称"),
                    DataVersion = table.Column<long>(type: "bigint", nullable: false, comment: "数据版本"),
                    Remark = table.Column<string>(type: "nvarchar(512)", maxLength: 512, nullable: false, comment: "角色描述"),
                    IsAdmin = table.Column<bool>(type: "bit", nullable: false, comment: "是否管理员角色"),
                    IsDefault = table.Column<bool>(type: "bit", nullable: false, comment: "是否默认角色"),
                    IsSystem = table.Column<bool>(type: "bit", nullable: false, comment: "是否系统角色"),
                    IsLocked = table.Column<bool>(type: "bit", nullable: false, comment: "是否锁定"),
                    CreatedTime = table.Column<DateTime>(type: "datetime2", nullable: false, comment: "创建时间"),
                    DeletedTime = table.Column<DateTime>(type: "datetime2", nullable: true, comment: "删除时间")
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_IDT_Role", x => x.Id);
                });

            migrationBuilder.CreateTable(
                name: "IDT_User",
                columns: table => new
                {
                    Id = table.Column<long>(type: "bigint", maxLength: 80, nullable: false, comment: "编号"),
                    UserName = table.Column<string>(type: "nvarchar(150)", maxLength: 150, nullable: false, comment: "用户名"),
                    NormalizedUserName = table.Column<string>(type: "nvarchar(450)", nullable: false, comment: "标准化的用户名"),
                    NickName = table.Column<string>(type: "nvarchar(150)", maxLength: 150, nullable: false, comment: "用户昵称"),
                    Email = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "电子邮箱"),
                    NormalizeEmail = table.Column<string>(type: "nvarchar(450)", nullable: false, comment: "标准化的电子邮箱"),
                    EmailConfirmed = table.Column<bool>(type: "bit", nullable: false, comment: "电子邮箱确认"),
                    PhoneNumber = table.Column<string>(type: "nvarchar(450)", nullable: false, comment: "手机号码"),
                    PhoneNumberConfirmed = table.Column<bool>(type: "bit", nullable: false, comment: "手机号码确定"),
                    HeadImg = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "用户头像"),
                    Remark = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "备注"),
                    PasswordHash = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "密码哈希值"),
                    TwoFactorEnabled = table.Column<bool>(type: "bit", nullable: false, comment: "双因子身份验证"),
                    LockoutEnd = table.Column<DateTimeOffset>(type: "datetimeoffset", nullable: true, comment: "锁定时间"),
                    LockoutEnabled = table.Column<bool>(type: "bit", nullable: false, comment: "是否登录锁"),
                    AccessFailedCount = table.Column<int>(type: "int", nullable: false, comment: "登录失败次数"),
                    IsSystem = table.Column<bool>(type: "bit", nullable: false, comment: "是否系统用户"),
                    RegisterType = table.Column<int>(type: "int", nullable: false, comment: "注册类型"),
                    SecurityStamp = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "安全标识"),
                    DataVersion = table.Column<long>(type: "bigint", nullable: false, comment: "数据版本"),
                    IsLocked = table.Column<bool>(type: "bit", nullable: false, comment: "是否锁定"),
                    CreatedTime = table.Column<DateTime>(type: "datetime2", nullable: false, comment: "创建时间"),
                    DeletedTime = table.Column<DateTime>(type: "datetime2", nullable: true, comment: "删除时间")
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_IDT_User", x => x.Id);
                });

            migrationBuilder.CreateTable(
                name: "SMS_SmsCaptcha",
                columns: table => new
                {
                    Id = table.Column<long>(type: "bigint", maxLength: 80, nullable: false, comment: "编号"),
                    Provider = table.Column<int>(type: "int", nullable: false, comment: "服务提供商"),
                    SignName = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "短信签名名称"),
                    TemplateCode = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "短信模板ID"),
                    BizId = table.Column<string>(type: "nvarchar(450)", nullable: false, comment: "发送回执ID"),
                    RequestId = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "请求ID"),
                    OutId = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "外部流水扩展字段"),
                    PhoneNumber = table.Column<string>(type: "nvarchar(150)", maxLength: 150, nullable: false, comment: "手机号码"),
                    SendDate = table.Column<DateTime>(type: "datetime2", nullable: false, comment: "发送日期"),
                    ReceiveDate = table.Column<DateTime>(type: "datetime2", nullable: false, comment: "接收日期"),
                    Message = table.Column<string>(type: "nvarchar(512)", maxLength: 512, nullable: false, comment: "信息内容"),
                    VerifyCode = table.Column<string>(type: "nvarchar(512)", maxLength: 512, nullable: false, comment: "验证码"),
                    ExpireMins = table.Column<decimal>(type: "decimal(22,10)", precision: 22, scale: 10, nullable: false, comment: "有效期分钟数"),
                    Verified = table.Column<bool>(type: "bit", nullable: false, comment: "已验证"),
                    VerifiedTime = table.Column<DateTime>(type: "datetime2", nullable: true, comment: "验证时间"),
                    CreatedTime = table.Column<DateTime>(type: "datetime2", nullable: false, comment: "创建时间")
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_SMS_SmsCaptcha", x => x.Id);
                });

            migrationBuilder.CreateTable(
                name: "SYS_KeyValue",
                columns: table => new
                {
                    Id = table.Column<Guid>(type: "uniqueidentifier", maxLength: 80, nullable: false, comment: "编号"),
                    ValueJson = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "数据值JSON"),
                    ValueType = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "数据值类型名"),
                    Key = table.Column<string>(type: "nvarchar(450)", nullable: false, comment: "数据键名"),
                    IsLocked = table.Column<bool>(type: "bit", nullable: false, comment: "是否锁定")
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_SYS_KeyValue", x => x.Id);
                });

            migrationBuilder.CreateTable(
                name: "AUD_AuditEntity",
                columns: table => new
                {
                    Id = table.Column<Guid>(type: "uniqueidentifier", maxLength: 80, nullable: false, comment: "编号"),
                    Name = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "实体名称"),
                    TypeName = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "类型名称"),
                    EntityKey = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "数据编号"),
                    OperateType = table.Column<int>(type: "int", nullable: false, comment: "操作类型"),
                    OperationId = table.Column<Guid>(type: "uniqueidentifier", nullable: false, comment: "所属审计操作编号")
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_AUD_AuditEntity", x => x.Id);
                    table.ForeignKey(
                        name: "FK_AuditEntity_OperationId",
                        column: x => x.OperationId,
                        principalTable: "AUD_AuditOperation",
                        principalColumn: "Id",
                        onDelete: ReferentialAction.Cascade);
                });

            migrationBuilder.CreateTable(
                name: "AUZ_ModuleFunction",
                columns: table => new
                {
                    Id = table.Column<Guid>(type: "uniqueidentifier", maxLength: 80, nullable: false, comment: "编号"),
                    ModuleId = table.Column<long>(type: "bigint", nullable: false, comment: "模块编号"),
                    FunctionId = table.Column<Guid>(type: "uniqueidentifier", nullable: false, comment: "功能编号")
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_AUZ_ModuleFunction", x => x.Id);
                    table.ForeignKey(
                        name: "FK_ModuleFunction_FunctionId",
                        column: x => x.FunctionId,
                        principalTable: "AUZ_Function",
                        principalColumn: "Id",
                        onDelete: ReferentialAction.Cascade);
                    table.ForeignKey(
                        name: "FK_ModuleFunction_ModuleId",
                        column: x => x.ModuleId,
                        principalTable: "AUZ_Module",
                        principalColumn: "Id",
                        onDelete: ReferentialAction.Cascade);
                });

            migrationBuilder.CreateTable(
                name: "IDT_OrganizationClaim",
                columns: table => new
                {
                    Id = table.Column<long>(type: "bigint", maxLength: 80, nullable: false, comment: "编号"),
                    OrganizationId = table.Column<long>(type: "bigint", nullable: false, comment: "组织机构编号"),
                    ClaimType = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "声明类型"),
                    ClaimValue = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "声明值"),
                    DataVersion = table.Column<long>(type: "bigint", nullable: false, comment: "数据版本")
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_IDT_OrganizationClaim", x => x.Id);
                    table.ForeignKey(
                        name: "FK_OrganizationClaim_OrganizationId",
                        column: x => x.OrganizationId,
                        principalTable: "IDT_Organization",
                        principalColumn: "Id",
                        onDelete: ReferentialAction.Cascade);
                });

            migrationBuilder.CreateTable(
                name: "AUZ_EntityRole",
                columns: table => new
                {
                    Id = table.Column<Guid>(type: "uniqueidentifier", maxLength: 80, nullable: false, comment: "编号"),
                    RoleId = table.Column<long>(type: "bigint", nullable: false, comment: "角色编号"),
                    EntityId = table.Column<Guid>(type: "uniqueidentifier", nullable: false, comment: "数据编号"),
                    Operation = table.Column<int>(type: "int", nullable: false, comment: "数据权限操作"),
                    FilterGroupJson = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "过滤条件组"),
                    DataVersion = table.Column<long>(type: "bigint", nullable: false, comment: "数据版本"),
                    IsLocked = table.Column<bool>(type: "bit", nullable: false, comment: "是否锁定"),
                    CreatedTime = table.Column<DateTime>(type: "datetime2", nullable: false, comment: "创建时间")
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_AUZ_EntityRole", x => x.Id);
                    table.ForeignKey(
                        name: "FK_EntityRole_EntityId",
                        column: x => x.EntityId,
                        principalTable: "AUZ_EntityInfo",
                        principalColumn: "Id",
                        onDelete: ReferentialAction.Cascade);
                    table.ForeignKey(
                        name: "FK_EntityRole_RoleId",
                        column: x => x.RoleId,
                        principalTable: "IDT_Role",
                        principalColumn: "Id",
                        onDelete: ReferentialAction.Cascade);
                });

            migrationBuilder.CreateTable(
                name: "AUZ_ModuleRole",
                columns: table => new
                {
                    Id = table.Column<Guid>(type: "uniqueidentifier", maxLength: 80, nullable: false, comment: "编号"),
                    ModuleId = table.Column<long>(type: "bigint", nullable: false, comment: "模块编号"),
                    RoleId = table.Column<long>(type: "bigint", nullable: false, comment: "角色编号")
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_AUZ_ModuleRole", x => x.Id);
                    table.ForeignKey(
                        name: "FK_ModuleRole_ModuleId",
                        column: x => x.ModuleId,
                        principalTable: "AUZ_Module",
                        principalColumn: "Id",
                        onDelete: ReferentialAction.Cascade);
                    table.ForeignKey(
                        name: "FK_ModuleRole_RoleId",
                        column: x => x.RoleId,
                        principalTable: "IDT_Role",
                        principalColumn: "Id",
                        onDelete: ReferentialAction.Cascade);
                });

            migrationBuilder.CreateTable(
                name: "IDT_RoleClaim",
                columns: table => new
                {
                    Id = table.Column<long>(type: "bigint", maxLength: 80, nullable: false, comment: "编号"),
                    RoleId = table.Column<long>(type: "bigint", nullable: false, comment: "角色编号"),
                    ClaimType = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "声明类型"),
                    ClaimValue = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "声明值"),
                    DataVersion = table.Column<long>(type: "bigint", nullable: false, comment: "数据版本")
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_IDT_RoleClaim", x => x.Id);
                    table.ForeignKey(
                        name: "FK_RoleClaim_RoleId",
                        column: x => x.RoleId,
                        principalTable: "IDT_Role",
                        principalColumn: "Id",
                        onDelete: ReferentialAction.Cascade);
                });

            migrationBuilder.CreateTable(
                name: "IDT_RoleOrganization",
                columns: table => new
                {
                    Id = table.Column<long>(type: "bigint", maxLength: 80, nullable: false, comment: "编号"),
                    RoleId = table.Column<long>(type: "bigint", nullable: false, comment: "角色编号"),
                    OrganizationId = table.Column<long>(type: "bigint", nullable: false, comment: "组织机构编号"),
                    DataVersion = table.Column<long>(type: "bigint", nullable: false, comment: "数据版本"),
                    CreatedTime = table.Column<DateTime>(type: "datetime2", nullable: false, comment: "创建时间"),
                    IsLocked = table.Column<bool>(type: "bit", nullable: false, comment: "是否锁定")
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_IDT_RoleOrganization", x => x.Id);
                    table.ForeignKey(
                        name: "FK_RoleOrganization_OrganizationId",
                        column: x => x.OrganizationId,
                        principalTable: "IDT_Organization",
                        principalColumn: "Id",
                        onDelete: ReferentialAction.Cascade);
                    table.ForeignKey(
                        name: "FK_RoleOrganization_RoleId",
                        column: x => x.RoleId,
                        principalTable: "IDT_Role",
                        principalColumn: "Id",
                        onDelete: ReferentialAction.Cascade);
                });

            migrationBuilder.CreateTable(
                name: "AUZ_EntityUser",
                columns: table => new
                {
                    Id = table.Column<Guid>(type: "uniqueidentifier", maxLength: 80, nullable: false, comment: "编号"),
                    UserId = table.Column<long>(type: "bigint", nullable: false, comment: "用户编号"),
                    EntityId = table.Column<Guid>(type: "uniqueidentifier", nullable: false, comment: "数据编号"),
                    FilterGroupJson = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "过滤条件组"),
                    DataVersion = table.Column<long>(type: "bigint", nullable: false, comment: "数据版本"),
                    IsLocked = table.Column<bool>(type: "bit", nullable: false, comment: "是否锁定"),
                    CreatedTime = table.Column<DateTime>(type: "datetime2", nullable: false, comment: "创建时间")
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_AUZ_EntityUser", x => x.Id);
                    table.ForeignKey(
                        name: "FK_EntityUser_EntityId",
                        column: x => x.EntityId,
                        principalTable: "AUZ_EntityInfo",
                        principalColumn: "Id",
                        onDelete: ReferentialAction.Cascade);
                    table.ForeignKey(
                        name: "FK_EntityUser_UserId",
                        column: x => x.UserId,
                        principalTable: "IDT_User",
                        principalColumn: "Id",
                        onDelete: ReferentialAction.Cascade);
                });

            migrationBuilder.CreateTable(
                name: "AUZ_ModuleUser",
                columns: table => new
                {
                    Id = table.Column<Guid>(type: "uniqueidentifier", maxLength: 80, nullable: false, comment: "编号"),
                    ModuleId = table.Column<long>(type: "bigint", nullable: false, comment: "模块编号"),
                    UserId = table.Column<long>(type: "bigint", nullable: false, comment: "用户编号"),
                    Disabled = table.Column<bool>(type: "bit", nullable: false, comment: "是否禁用")
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_AUZ_ModuleUser", x => x.Id);
                    table.ForeignKey(
                        name: "FK_ModuleUser_ModuleId",
                        column: x => x.ModuleId,
                        principalTable: "AUZ_Module",
                        principalColumn: "Id",
                        onDelete: ReferentialAction.Cascade);
                    table.ForeignKey(
                        name: "FK_ModuleUser_UserId",
                        column: x => x.UserId,
                        principalTable: "IDT_User",
                        principalColumn: "Id",
                        onDelete: ReferentialAction.Cascade);
                });

            migrationBuilder.CreateTable(
                name: "IDT_LoginLog",
                columns: table => new
                {
                    Id = table.Column<long>(type: "bigint", maxLength: 80, nullable: false, comment: "编号"),
                    Ip = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "登录IP"),
                    UserAgent = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "用户代理"),
                    LogoutTime = table.Column<DateTime>(type: "datetime2", nullable: true, comment: "退出时间"),
                    CreatedTime = table.Column<DateTime>(type: "datetime2", nullable: false, comment: "创建时间"),
                    UserId = table.Column<long>(type: "bigint", nullable: false, comment: "用户编号")
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_IDT_LoginLog", x => x.Id);
                    table.ForeignKey(
                        name: "FK_LoginLog_UserId",
                        column: x => x.UserId,
                        principalTable: "IDT_User",
                        principalColumn: "Id",
                        onDelete: ReferentialAction.Cascade);
                });

            migrationBuilder.CreateTable(
                name: "IDT_UserClaim",
                columns: table => new
                {
                    Id = table.Column<long>(type: "bigint", maxLength: 80, nullable: false, comment: "编号"),
                    UserId = table.Column<long>(type: "bigint", nullable: false, comment: "用户编号"),
                    ClaimType = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "声明类型"),
                    ClaimValue = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "声明值"),
                    DataVersion = table.Column<long>(type: "bigint", nullable: false, comment: "数据版本")
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_IDT_UserClaim", x => x.Id);
                    table.ForeignKey(
                        name: "FK_UserClaim_UserId",
                        column: x => x.UserId,
                        principalTable: "IDT_User",
                        principalColumn: "Id",
                        onDelete: ReferentialAction.Cascade);
                });

            migrationBuilder.CreateTable(
                name: "IDT_UserDetail",
                columns: table => new
                {
                    Id = table.Column<long>(type: "bigint", maxLength: 80, nullable: false, comment: "编号"),
                    RegisterIp = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "注册IP"),
                    UserId = table.Column<long>(type: "bigint", nullable: false, comment: "用户编号")
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_IDT_UserDetail", x => x.Id);
                    table.ForeignKey(
                        name: "FK_UserDetail_UserId",
                        column: x => x.UserId,
                        principalTable: "IDT_User",
                        principalColumn: "Id",
                        onDelete: ReferentialAction.Cascade);
                });

            migrationBuilder.CreateTable(
                name: "IDT_UserLogin",
                columns: table => new
                {
                    Id = table.Column<long>(type: "bigint", maxLength: 80, nullable: false, comment: "编号"),
                    LoginProvider = table.Column<string>(type: "nvarchar(450)", nullable: false, comment: "登录的登录提供程序"),
                    ProviderKey = table.Column<string>(type: "nvarchar(450)", nullable: false, comment: "第三方用户的唯一标识"),
                    ProviderDisplayName = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "第三方用户昵称"),
                    Avatar = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "第三方用户头像"),
                    UserId = table.Column<long>(type: "bigint", nullable: false, comment: "用户编号"),
                    CreatedTime = table.Column<DateTime>(type: "datetime2", nullable: false, comment: "创建时间")
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_IDT_UserLogin", x => x.Id);
                    table.ForeignKey(
                        name: "FK_UserLogin_UserId",
                        column: x => x.UserId,
                        principalTable: "IDT_User",
                        principalColumn: "Id",
                        onDelete: ReferentialAction.Cascade);
                });

            migrationBuilder.CreateTable(
                name: "IDT_UserOrganization",
                columns: table => new
                {
                    Id = table.Column<long>(type: "bigint", maxLength: 80, nullable: false, comment: "编号"),
                    UserId = table.Column<long>(type: "bigint", nullable: false, comment: "用户编号"),
                    OrganizationId = table.Column<long>(type: "bigint", nullable: false, comment: "组织机构编号"),
                    DataVersion = table.Column<long>(type: "bigint", nullable: false, comment: "数据版本"),
                    CreatedTime = table.Column<DateTime>(type: "datetime2", nullable: false, comment: "创建时间"),
                    IsLocked = table.Column<bool>(type: "bit", nullable: false, comment: "是否锁定")
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_IDT_UserOrganization", x => x.Id);
                    table.ForeignKey(
                        name: "FK_UserOrganization_OrganizationId",
                        column: x => x.OrganizationId,
                        principalTable: "IDT_Organization",
                        principalColumn: "Id",
                        onDelete: ReferentialAction.Cascade);
                    table.ForeignKey(
                        name: "FK_UserOrganization_UserId",
                        column: x => x.UserId,
                        principalTable: "IDT_User",
                        principalColumn: "Id",
                        onDelete: ReferentialAction.Cascade);
                });

            migrationBuilder.CreateTable(
                name: "IDT_UserRole",
                columns: table => new
                {
                    Id = table.Column<long>(type: "bigint", maxLength: 80, nullable: false, comment: "编号"),
                    UserId = table.Column<long>(type: "bigint", nullable: false, comment: "用户编号"),
                    RoleId = table.Column<long>(type: "bigint", nullable: false, comment: "角色编号"),
                    CreatedTime = table.Column<DateTime>(type: "datetime2", nullable: false, comment: "创建时间"),
                    IsLocked = table.Column<bool>(type: "bit", nullable: false, comment: "是否锁定")
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_IDT_UserRole", x => x.Id);
                    table.ForeignKey(
                        name: "FK_UserRole_RoleId",
                        column: x => x.RoleId,
                        principalTable: "IDT_Role",
                        principalColumn: "Id",
                        onDelete: ReferentialAction.Cascade);
                    table.ForeignKey(
                        name: "FK_UserRole_UserId",
                        column: x => x.UserId,
                        principalTable: "IDT_User",
                        principalColumn: "Id",
                        onDelete: ReferentialAction.Cascade);
                });

            migrationBuilder.CreateTable(
                name: "IDT_UserToken",
                columns: table => new
                {
                    Id = table.Column<long>(type: "bigint", maxLength: 80, nullable: false, comment: "编号"),
                    UserId = table.Column<long>(type: "bigint", nullable: false, comment: "用户编号"),
                    LoginProvider = table.Column<string>(type: "nvarchar(450)", nullable: false, comment: "登录提供者"),
                    Name = table.Column<string>(type: "nvarchar(450)", nullable: false, comment: "令牌名称"),
                    Value = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "令牌值")
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_IDT_UserToken", x => x.Id);
                    table.ForeignKey(
                        name: "FK_UserToken_UserId",
                        column: x => x.UserId,
                        principalTable: "IDT_User",
                        principalColumn: "Id",
                        onDelete: ReferentialAction.Cascade);
                });

            migrationBuilder.CreateTable(
                name: "AUD_AuditProperty",
                columns: table => new
                {
                    Id = table.Column<Guid>(type: "uniqueidentifier", maxLength: 80, nullable: false, comment: "编号"),
                    DisplayName = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "显示名称"),
                    FieldName = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "字段"),
                    OriginalValue = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "旧值"),
                    NewValue = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "新值"),
                    DataType = table.Column<string>(type: "nvarchar(max)", nullable: false, comment: "数据类型"),
                    AuditEntityId = table.Column<Guid>(type: "uniqueidentifier", nullable: false, comment: "所属审计实体编号")
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_AUD_AuditProperty", x => x.Id);
                    table.ForeignKey(
                        name: "FK_AuditProperty_AuditEntityId",
                        column: x => x.AuditEntityId,
                        principalTable: "AUD_AuditEntity",
                        principalColumn: "Id",
                        onDelete: ReferentialAction.Cascade);
                });

            migrationBuilder.CreateIndex(
                name: "IX_AuditEntity_OperationId",
                table: "AUD_AuditEntity",
                column: "OperationId");

            migrationBuilder.CreateIndex(
                name: "IX_AuditProperty_AuditEntityId",
                table: "AUD_AuditProperty",
                column: "AuditEntityId");

            migrationBuilder.CreateIndex(
                name: "IDX_EntityInfo_TypeName",
                table: "AUZ_EntityInfo",
                column: "TypeName",
                unique: true);

            migrationBuilder.CreateIndex(
                name: "IX_AUZ_EntityRole_DataVersion",
                table: "AUZ_EntityRole",
                column: "DataVersion");

            migrationBuilder.CreateIndex(
                name: "IX_AUZ_EntityRole_RoleId",
                table: "AUZ_EntityRole",
                column: "RoleId");

            migrationBuilder.CreateIndex(
                name: "IX_EntityRole_EntityRoleOperation",
                table: "AUZ_EntityRole",
                columns: new[] { "EntityId", "RoleId", "Operation" });

            migrationBuilder.CreateIndex(
                name: "IX_AUZ_EntityUser_DataVersion",
                table: "AUZ_EntityUser",
                column: "DataVersion");

            migrationBuilder.CreateIndex(
                name: "IX_AUZ_EntityUser_UserId",
                table: "AUZ_EntityUser",
                column: "UserId");

            migrationBuilder.CreateIndex(
                name: "IX_EntityUser_Ids",
                table: "AUZ_EntityUser",
                columns: new[] { "EntityId", "UserId" });

            migrationBuilder.CreateIndex(
                name: "IDX_Function_AreaControllerAction",
                table: "AUZ_Function",
                columns: new[] { "Area", "Controller", "Action" },
                unique: true);

            migrationBuilder.CreateIndex(
                name: "IDX_Module_TreePathString",
                table: "AUZ_Module",
                column: "TreePathString",
                unique: true);

            migrationBuilder.CreateIndex(
                name: "IX_AUZ_Module_ParentId",
                table: "AUZ_Module",
                column: "ParentId");

            migrationBuilder.CreateIndex(
                name: "IDX_ModuleFunction_Ids",
                table: "AUZ_ModuleFunction",
                columns: new[] { "ModuleId", "FunctionId" },
                unique: true);

            migrationBuilder.CreateIndex(
                name: "IX_AUZ_ModuleFunction_FunctionId",
                table: "AUZ_ModuleFunction",
                column: "FunctionId");

            migrationBuilder.CreateIndex(
                name: "IDX_ModuleRole_Ids",
                table: "AUZ_ModuleRole",
                columns: new[] { "ModuleId", "RoleId" },
                unique: true);

            migrationBuilder.CreateIndex(
                name: "IX_AUZ_ModuleRole_RoleId",
                table: "AUZ_ModuleRole",
                column: "RoleId");

            migrationBuilder.CreateIndex(
                name: "IDX_ModuleUser_Ids",
                table: "AUZ_ModuleUser",
                columns: new[] { "ModuleId", "UserId" },
                unique: true);

            migrationBuilder.CreateIndex(
                name: "IX_AUZ_ModuleUser_UserId",
                table: "AUZ_ModuleUser",
                column: "UserId");

            migrationBuilder.CreateIndex(
                name: "IDX_Demo_Guid",
                table: "DMO_Demo",
                column: "Guid",
                unique: true);

            migrationBuilder.CreateIndex(
                name: "IDX_Demo_String",
                table: "DMO_Demo",
                columns: new[] { "String", "DeletedTime" },
                unique: true);

            migrationBuilder.CreateIndex(
                name: "IX_Demo_OrganizationId",
                table: "DMO_Demo",
                column: "OrganizationId");

            migrationBuilder.CreateIndex(
                name: "IX_DMO_Demo_DataVersion",
                table: "DMO_Demo",
                column: "DataVersion");

            migrationBuilder.CreateIndex(
                name: "IX_FileArchive_FileIntroId",
                table: "FIE_FileArchive",
                column: "FileIntroId");

            migrationBuilder.CreateIndex(
                name: "IX_FileArchive_HashMD5",
                table: "FIE_FileArchive",
                columns: new[] { "SHA1", "MD5" });

            migrationBuilder.CreateIndex(
                name: "IX_FileArchive_UploadSrcIdt",
                table: "FIE_FileArchive",
                columns: new[] { "UploadSource", "UploadIdent" });

            migrationBuilder.CreateIndex(
                name: "IX_FIE_FileContent_DataVersion",
                table: "FIE_FileContent",
                column: "DataVersion");

            migrationBuilder.CreateIndex(
                name: "IX_FileContent_FileIntroId",
                table: "FIE_FileContent",
                column: "FileIntroId");

            migrationBuilder.CreateIndex(
                name: "IX_FileContent_HashMD5",
                table: "FIE_FileContent",
                columns: new[] { "SHA1", "MD5" });

            migrationBuilder.CreateIndex(
                name: "IX_FIE_FileIntro_DataVersion",
                table: "FIE_FileIntro",
                column: "DataVersion");

            migrationBuilder.CreateIndex(
                name: "IX_FileIntro_FileExt",
                table: "FIE_FileIntro",
                column: "FileExt");

            migrationBuilder.CreateIndex(
                name: "IX_FileIntro_FileName",
                table: "FIE_FileIntro",
                column: "FileName");

            migrationBuilder.CreateIndex(
                name: "IX_FileIntro_HashMD5",
                table: "FIE_FileIntro",
                columns: new[] { "SHA1", "MD5" });

            migrationBuilder.CreateIndex(
                name: "IX_FileIntro_UploadSrcIdt",
                table: "FIE_FileIntro",
                columns: new[] { "UploadSource", "UploadIdent" });

            migrationBuilder.CreateIndex(
                name: "IX_FileRecord_FileIntroId",
                table: "FIE_FileRecord",
                column: "FileIntroId");

            migrationBuilder.CreateIndex(
                name: "IX_FileRecord_RecordType",
                table: "FIE_FileRecord",
                column: "RecordType");

            migrationBuilder.CreateIndex(
                name: "IX_IDT_LoginLog_UserId",
                table: "IDT_LoginLog",
                column: "UserId");

            migrationBuilder.CreateIndex(
                name: "IDX_Organization_NormalizedName",
                table: "IDT_Organization",
                columns: new[] { "NormalizedName", "ParentId", "DeletedTime" },
                unique: true);

            migrationBuilder.CreateIndex(
                name: "IDX_Organization_OrgName",
                table: "IDT_Organization",
                columns: new[] { "OrgName", "ParentId", "DeletedTime" },
                unique: true);

            migrationBuilder.CreateIndex(
                name: "IDX_Organization_TreePathString",
                table: "IDT_Organization",
                column: "TreePathString",
                unique: true);

            migrationBuilder.CreateIndex(
                name: "IX_IDT_Organization_DataVersion",
                table: "IDT_Organization",
                column: "DataVersion");

            migrationBuilder.CreateIndex(
                name: "IX_Organization_ParentId",
                table: "IDT_Organization",
                column: "ParentId");

            migrationBuilder.CreateIndex(
                name: "IX_IDT_OrganizationClaim_DataVersion",
                table: "IDT_OrganizationClaim",
                column: "DataVersion");

            migrationBuilder.CreateIndex(
                name: "IX_IDT_OrganizationClaim_OrganizationId",
                table: "IDT_OrganizationClaim",
                column: "OrganizationId");

            migrationBuilder.CreateIndex(
                name: "IDX_Role_RoleName",
                table: "IDT_Role",
                columns: new[] { "NormalizedName", "DeletedTime" },
                unique: true);

            migrationBuilder.CreateIndex(
                name: "IX_IDT_Role_DataVersion",
                table: "IDT_Role",
                column: "DataVersion");

            migrationBuilder.CreateIndex(
                name: "IX_IDT_RoleClaim_DataVersion",
                table: "IDT_RoleClaim",
                column: "DataVersion");

            migrationBuilder.CreateIndex(
                name: "IX_IDT_RoleClaim_RoleId",
                table: "IDT_RoleClaim",
                column: "RoleId");

            migrationBuilder.CreateIndex(
                name: "IDX_RoleOrganization_Ids",
                table: "IDT_RoleOrganization",
                columns: new[] { "RoleId", "OrganizationId" },
                unique: true);

            migrationBuilder.CreateIndex(
                name: "IX_IDT_RoleOrganization_DataVersion",
                table: "IDT_RoleOrganization",
                column: "DataVersion");

            migrationBuilder.CreateIndex(
                name: "IX_IDT_RoleOrganization_OrganizationId",
                table: "IDT_RoleOrganization",
                column: "OrganizationId");

            migrationBuilder.CreateIndex(
                name: "IDX_User_UserEmail",
                table: "IDT_User",
                columns: new[] { "NormalizedUserName", "NormalizeEmail", "DeletedTime" },
                unique: true);

            migrationBuilder.CreateIndex(
                name: "IDX_User_UserName",
                table: "IDT_User",
                columns: new[] { "NormalizedUserName", "DeletedTime" },
                unique: true);

            migrationBuilder.CreateIndex(
                name: "IDX_User_UserPhoneNumber",
                table: "IDT_User",
                columns: new[] { "NormalizedUserName", "PhoneNumber", "DeletedTime" },
                unique: true);

            migrationBuilder.CreateIndex(
                name: "IX_IDT_User_DataVersion",
                table: "IDT_User",
                column: "DataVersion");

            migrationBuilder.CreateIndex(
                name: "IX_IDT_UserClaim_DataVersion",
                table: "IDT_UserClaim",
                column: "DataVersion");

            migrationBuilder.CreateIndex(
                name: "IX_IDT_UserClaim_UserId",
                table: "IDT_UserClaim",
                column: "UserId");

            migrationBuilder.CreateIndex(
                name: "IX_IDT_UserDetail_UserId",
                table: "IDT_UserDetail",
                column: "UserId",
                unique: true);

            migrationBuilder.CreateIndex(
                name: "IDX_UserLogin_Provider",
                table: "IDT_UserLogin",
                columns: new[] { "LoginProvider", "ProviderKey" },
                unique: true);

            migrationBuilder.CreateIndex(
                name: "IX_IDT_UserLogin_UserId",
                table: "IDT_UserLogin",
                column: "UserId");

            migrationBuilder.CreateIndex(
                name: "IDX_UserOrganization_Ids",
                table: "IDT_UserOrganization",
                columns: new[] { "UserId", "OrganizationId" },
                unique: true);

            migrationBuilder.CreateIndex(
                name: "IX_IDT_UserOrganization_DataVersion",
                table: "IDT_UserOrganization",
                column: "DataVersion");

            migrationBuilder.CreateIndex(
                name: "IX_IDT_UserOrganization_OrganizationId",
                table: "IDT_UserOrganization",
                column: "OrganizationId");

            migrationBuilder.CreateIndex(
                name: "IDX_UserRole_Ids",
                table: "IDT_UserRole",
                columns: new[] { "UserId", "RoleId" },
                unique: true);

            migrationBuilder.CreateIndex(
                name: "IX_IDT_UserRole_RoleId",
                table: "IDT_UserRole",
                column: "RoleId");

            migrationBuilder.CreateIndex(
                name: "IDX_UserToken_Token",
                table: "IDT_UserToken",
                columns: new[] { "UserId", "LoginProvider", "Name" },
                unique: true);

            migrationBuilder.CreateIndex(
                name: "IX_SmsCaptcha_PhoneBiz",
                table: "SMS_SmsCaptcha",
                columns: new[] { "PhoneNumber", "Provider", "BizId", "VerifyCode", "Verified" });

            migrationBuilder.CreateIndex(
                name: "IX_SmsCaptcha_Provider",
                table: "SMS_SmsCaptcha",
                column: "Provider");

            migrationBuilder.CreateIndex(
                name: "IX_SmsCaptcha_SendDate",
                table: "SMS_SmsCaptcha",
                column: "SendDate");

            migrationBuilder.CreateIndex(
                name: "IX_KeyValue_Key",
                table: "SYS_KeyValue",
                column: "Key");
        }

        protected override void Down(MigrationBuilder migrationBuilder)
        {
            migrationBuilder.DropTable(
                name: "AUD_AuditProperty");

            migrationBuilder.DropTable(
                name: "AUZ_EntityRole");

            migrationBuilder.DropTable(
                name: "AUZ_EntityUser");

            migrationBuilder.DropTable(
                name: "AUZ_ModuleFunction");

            migrationBuilder.DropTable(
                name: "AUZ_ModuleRole");

            migrationBuilder.DropTable(
                name: "AUZ_ModuleUser");

            migrationBuilder.DropTable(
                name: "DMO_Demo");

            migrationBuilder.DropTable(
                name: "FIE_FileArchive");

            migrationBuilder.DropTable(
                name: "FIE_FileContent");

            migrationBuilder.DropTable(
                name: "FIE_FileIntro");

            migrationBuilder.DropTable(
                name: "FIE_FileRecord");

            migrationBuilder.DropTable(
                name: "IDT_LoginLog");

            migrationBuilder.DropTable(
                name: "IDT_OrganizationClaim");

            migrationBuilder.DropTable(
                name: "IDT_RoleClaim");

            migrationBuilder.DropTable(
                name: "IDT_RoleOrganization");

            migrationBuilder.DropTable(
                name: "IDT_UserClaim");

            migrationBuilder.DropTable(
                name: "IDT_UserDetail");

            migrationBuilder.DropTable(
                name: "IDT_UserLogin");

            migrationBuilder.DropTable(
                name: "IDT_UserOrganization");

            migrationBuilder.DropTable(
                name: "IDT_UserRole");

            migrationBuilder.DropTable(
                name: "IDT_UserToken");

            migrationBuilder.DropTable(
                name: "SMS_SmsCaptcha");

            migrationBuilder.DropTable(
                name: "SYS_KeyValue");

            migrationBuilder.DropTable(
                name: "AUD_AuditEntity");

            migrationBuilder.DropTable(
                name: "AUZ_EntityInfo");

            migrationBuilder.DropTable(
                name: "AUZ_Function");

            migrationBuilder.DropTable(
                name: "AUZ_Module");

            migrationBuilder.DropTable(
                name: "IDT_Organization");

            migrationBuilder.DropTable(
                name: "IDT_Role");

            migrationBuilder.DropTable(
                name: "IDT_User");

            migrationBuilder.DropTable(
                name: "AUD_AuditOperation");
        }
    }
}
